<template>
  <div class="add-quotation">
    <el-dialog
      :title="'用户详情'"
      :visible.sync="editConfig.visible"
      :width="dialogWidth"
      :before-close="handleClose"
      append-to-body
      custom-class="iframe-dialog"
    >
      <div class="drawerContent" style="overflow: auto">
        <el-form ref="form" :rules="rules" :model="editConfig.form" label-position="right" label-width="100px">
          <el-form-item label="用户名:" prop="username">
            <el-input v-model="editConfig.form.username" placeholder="--" disabled></el-input>
          </el-form-item>
          <el-form-item label="密码:" prop="password">
            <el-input v-model="editConfig.form.password" placeholder="--" disabled></el-input>
          </el-form-item>
          <el-form-item label="手机号:" prop="phone">
            <el-input-number
              v-model="editConfig.form.phone"
              placeholder=""
              :min="0"
              :controls="false"
              disabled
              style="width: 100%"
            ></el-input-number>
          </el-form-item>
          <el-form-item label="公司名称:" prop="companyName">
            <el-input v-model="editConfig.form.company" placeholder="--" disabled></el-input>
          </el-form-item>
          <el-form-item label="联系人名称:" prop="nickName">
            <el-input v-model="editConfig.form.contact" placeholder="--" disabled></el-input>
          </el-form-item>
          <el-form-item label="邮箱:" prop="companyEmail">
            <el-input v-model="editConfig.form.email" placeholder="--" disabled></el-input>
          </el-form-item>
          <el-form-item label="行业:" prop="industry">
            <el-input v-model="editConfig.form.industry" placeholder="--" disabled></el-input>
          </el-form-item>
          <el-form-item label="地区:" prop="region">
            <el-input v-model="editConfig.form.region" placeholder="--" disabled></el-input>
          </el-form-item>
          <el-form-item label="用户等级:" prop="roleIDs">
            <el-checkbox-group v-model="editConfig.form.roleIDs">
              <el-checkbox v-for="role in roleList" :label="role.id" :key="role.id">{{ role.name }}</el-checkbox>
            </el-checkbox-group>
          </el-form-item>
        </el-form>
      </div>
      <div slot="footer" class="dialog-footer">
        <el-button @click="handleClose">取消</el-button>
        <el-button v-if="editConfig.title == '查看' ? false : true" type="primary" @click="onSubmit('form')"
          >确定</el-button
        >
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { getRoleIDs } from "@/api/unifiedManage/userManage"
export default {
  name: "EditUserInfo",
  props: {
    editCommonConfig: {
      type: Object,
      default: () => {
        return {
          visible: false,
          title: "新建",
          form: {}
        }
      }
    }
  },
  components: {},
  computed: {},
  data() {
    return {
      dialogWidth: "30%",
      editConfig: this.editCommonConfig,
      // form: {},
      rules: {
        username: [{ required: true, message: "请输入用户名", trigger: "blur" }],
        password: [{ required: true, message: "请输入密码", trigger: "blur" }],
        phone: [{ required: true, message: "请输入手机号", trigger: "blur" }],
        companyName: [{ required: true, message: "请输入公司名称", trigger: "blur" }],
        nickName: [{ required: true, message: "请输入联系人名称", trigger: "blur" }],
        roleIDs: [{ required: true, message: "请选择用户等级", trigger: "change" }]
      },
      roleList: [] // 用户等级
    }
  },
  watch: {
    "editCommonConfig.visible"(val) {
      console.log("sssssssssss")
      if (val) {
        // this.formInfo()
        console.log(val)
      }
    },
    "editCommonConfig.form.username"(val) {
      console.log(val)
      if (this.editConfig.visible) {
        this.$refs.form.resetFields()
        if (val.id) {
          // this.getDataInfo(val)
        }
      }
    }
  },
  created() {
    this.getDataInfo()
  },
  methods: {
    handleClose() {
      this.editConfig.visible = false
    },
    // 获取等级信息
    async getDataInfo() {
      const rsp = await getRoleIDs({ useType: 1 })
      if (rsp.code == 200) {
        this.roleList = rsp.data ? rsp.data : []
      }
    }
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped>
::v-deep {
  .iframe-dialog .el-dialog__body {
    .drawerContent {
      width: 80%;
      padding: 20px 0;
      margin: auto;
      overflow: hidden;
      margin-top: 15px;
      // 溢出隐藏滚动条
      scrollbar-width: none; /* firefox */
      -ms-overflow-style: none; /* IE 10+ */
    }
  }
  .el-dialog__footer {
    background-color: #f5f5f5;
    height: 55px;
    line-height: 55px;
    text-align: right;
    padding-right: 20px;
  }
  .el-input__inner {
    text-align: left;
  }
}
</style>
